from eloquentarduino.ml import data
from eloquentarduino.ml import plot
from eloquentarduino.ml.data import Pipeline
from eloquentarduino.ml.data import PipelineGridSearch
# @deprecated
#from eloquentarduino.ml.Classifier import Classifier
